@@ -57,7 +57,7 @@ class PixBtn(QToolButton):  #klasa ikon z miniaturami
     self.setMenu(self.pop)
     self.setMinimumHeight(115)
     self.setMinimumWidth(115)
-    self.setMaximumWidth(182)
+    self.setMaximumWidth(115)
     self.setMaximumHeight(115)    
     self.setStyleSheet("background-color: rgba(0,0,0,0%);")
     self.clicked.connect(self.clickk)
@@ -479,7 +479,8 @@ class Main(QMainWindow): ################## Main Class ##################
 #        print str(a)+".jpeg"
         self.miniaturki[i] = (str(a)+".jpeg")
       else:
-        print "nie ma", self.listForSum[i], self.licz[i]
+        print "no thumbnail for ", self.listForSum[i], self.licz[i]
+        self.miniaturki[i] = (str(a)+".jpeg")
 #    print self.miniaturki
     os.chdir("/home/user/.thumbnails/cropped")
  
@@ -534,6 +535,24 @@ class Main(QMainWindow): ################## Main Class ##################
           self.pathList[i] = self.licz[i]
         else:
           print "null pixmap", self.licz[i]
+          print "making thumb",
+          os.chdir(self.dirPix)
+          self.reader.setFileName(self.licz[i])
+          self.reader.setScaledSize(QSize(182,115))
+          pixmap = QPixmap(self.reader.read())#.scaledToHeight(115)#self.licz[i])#self.reader.read()).scaledToHeight(115)
+#          pixmap.scaled(115,115)
+          if pixmap.isNull():
+            print "Unknown error while loading image"
+          self.miniatures[i] = PixBtn(self, self.licz[i], i, self.label)
+          self.miniatures[i].setIconSize(QSize(pixmap.width(),pixmap.height()))
+          self.miniatures[i].setIcon(QIcon(pixmap))
+          self.miniatures[i].blockSignals(True)
+          #self.miniatures[i].clicked.connect(self.showPix)
+          self.layoutLandscape.addWidget(self.miniatures[i],j,k)
+          k+=1
+          self.pathList[i] = self.licz[i]
+          os.chdir("/home/user/.thumbnails/cropped")
+        
           
 #        QApplication.processEvents()
         #przesuwanie okna za ladowanymi zdjeciami
@@ -606,6 +625,8 @@ class Main(QMainWindow): ################## Main Class ##################
   def showPix(self, index):
     if self.pix == None:
       self.pix = PixWindow(self.dbus, self.licz, index, self)
+    self.pix.flag = 0
+    self.pix.loadBetterFlag = 0
     self.pix.index = index
     self.pix.setStyleSheet("QToolButton { background-color: rgba(0,0,0,0%); }")
     self.pix.setWindowTitle(str(self.licz[index]))
